@@ -18,18 +18,10 @@ struct latency_test_info {
 	unsigned char comm[MAX_PROC_CNTS][16];
 };
 
-struct ksym_lookup_info {
-	unsigned long addr;	/* addr to look up */
-	char name[128];
-	unsigned long offset;
-	unsigned long size;
-};
-
 #define LAT_TEST_FREQ	_IOW('t', 0x01, unsigned long)
 #define LAT_TEST_COUNT	_IOW('t', 0x02, unsigned long)
 #define LAT_TEST_START	_IO('t', 0x03)
 #define LAT_TEST_STOP	_IO('t', 0x04)
 #define LAT_TEST_READ	_IOR('t', 0x05, struct latency_test_info)
-#define LAT_TEST_GETSYMBOL	_IOWR('t', 0x06, struct ksym_lookup_info)
 
 #endif
